# Neck-Through Modification (Firebird/Bass Style)

Modifies the Electric 6-String DAG.

## Changes
- **Concept:** The Neck IS the center of the body. Wings are glued on.
- **Remove:** Neck Pocket, Neck Screws.

## Modified Sequence
1.  **Laminate_Neck_Blank** -> Start (Multi-piece laminate)
2.  **Glue_Wings** -> Laminate_Neck_Blank
3.  **Cut_Body_Shape** -> Glue_Wings (Cut the wings and neck center as one)
20. **Route_Pickup_Cavities** -> Cut_Body_Shape
31. **Final_Sanding** -> Route_Pickup_Cavities
